# license.sh

>  License-audits utility for your project.

## Description

This tool allows you to run `license-sh` in your project directory to
verify the project's software dependencies.

The goal is to create an open-source utility that helps companies do a
software audit of their 3rd party dependencies.

We created license.sh because we wanted a license audit tool that has
the following features:

- **Easy to use** 
  -   Simply run `license-sh` inside your project directory to get a
      basic overview.
  -   Type `license-sh --help` for more options.
- **Open source** - We want this software to be open-source, so that
  it's available for everyone. It is **not** an open-source wrapper for
  an enterprise product. You can freely modify or extend it and run it
  without limitations.
     
     The source code is licensed under `MIT` license and
     available at
     [@webscopeio/license.sh](https://github.com/webscopeio/license.sh)
     
- **Community driven** - We were missing a place where IT professionals
  could help each other with licensing & legal questions. Feel free to
  join:
    - [License.sh Slack channel]()
    - [License.sh Forum]()
  
- **Enterprise ready support** (Optional)
  - In case you need more advanced features, we provide you a
    [platform]() where you can start doing license audits on more
    professional level with **zero-infrastructure** and
    **zero-maintenance**.
    

## Language support
 
We currently support the following package managers. We will add more
languages soon! Please let us know what languages to prioritize in [this
form]() and we will let you know once we add support for them.

* Javascript
  * NPM
  * Yarn
* Python :snake:
  * pipenv
  

